module.exports = (debug) => (xml) => {
  debug('Drugs', 'Processing started');
  const source = xml.root.report[0].highImpactResult;
  if(!source) {
    debug('Drugs', 'Data not available');
    return undefined;
  }

  const clinicalAssociations = {
    '0': 'benefit',
    '1': 'lack of benefit',
    '2': 'uncertain'
  };

  try {
    debug('Drugs', 'Processing finished');
    return source.map(i => ({
      name: i.highImpactDrugs?.[0]?.replace(/(\r\n|\n|\r)/gm,""),
      biomarker: i.biomarkerName?.[0].replace(/(\r\n|\n|\r)/gm,""),
      method: i.method?.[0],
      analyte: i.analyte?.[0],
      result:i.result1?.[0]?.trim().replace(/(\r\n|\n|\r)/gm,""),
      level: i.level?.[0] !== 'Level 99' ? i.level?.[0] : null,
      clinicalAssociation: clinicalAssociations[i.clinicalAssociation?.[0]] || null,
      comment: i.level?.[0] === 'Level 99' ? i.comment?.[0] || undefined : undefined,
      bold: i.highlightText?.[0] === 'true'
    }));
  }
  catch(err) {
    debug('Drugs', err);
    return undefined;
  }
}
