module.exports = (debug) => (xml) => {
  debug('TrackResults', 'Processing started');
  const source = xml.root.report[0].trackResults?.[0].trackResult;
  if (!source) {
    debug('TrackResults', 'Data not available');
    return undefined;
  }

  function extractGene (i) {
    return {
      biomarker: i.biomarker?.[0].replace(/(\r\n|\n|\r)/gm,""),
      variant: i.variant?.[0],
      dnaChange: i.dnaChange?.[0],
      interpreation: i.interpreation?.[0],
      isRelevantResult: i.isRelevantResult?.[0],
      cprv: i.cprv?.[0],
      unit: i.unit?.[0],
      resultType: i.resultType?.[0],
      profileType: i.profileType_1?.[0],
      plasma: i.plasma_1?.[0],
      currentCase_plasma: i.currentCase_plasma?.[0],
      result: i.result_1?.[0]
    };
  }

  let results;

  try {
    if(source?.length) {
      debug('TrackResults', 'Extracting track results started');
      results = source.map(extractGene);
      debug('TrackResults', 'Extracting track results finished');
    }
    else {
      debug('TrackResults', 'Track results source not available');
      results = [];
    }
  }
  catch(err) {
    debug('TrackResults', err);
    return undefined;
  }

  results = results.filter(r => ['Blood TMB', 'Microsatellite Instability', 'Tumor Fraction'].includes(r.biomarker))

  debug('TrackResults', 'Processing finished');
  return results;
};
