const xml2js = require('xml2js');
const debug = require('debug')('xmlreport-reader');

const headerModule = require('./extractors/header')(debug);
const specimenModule = require('./extractors/specimen')(debug);
const drugsModule = require('./extractors/drugs')(debug);
const ihcModule = require('./extractors/ihc')(debug);
const genomicSignaturesModule = require('./extractors/genomicSignatures')(debug);
const trackResultsModule = require('./extractors/trackResults')(debug);
const cancerRelevantModule = require('./extractors/cancerRelevantBiomarkers')(debug);
const genesModule = require('./extractors/genes')(debug);
const referencesModule = require('./extractors/references')(debug);
const hlaTestsModule = require('./extractors/hlaTests')(debug);
const ctcTrialsModule = require('./extractors/ctcClinicalTrials')(debug);
const gpsModule = require('./extractors/gps')(debug);
const cishModule = require('./extractors/cish')(debug);
const fishModule = require('./extractors/fish')(debug);
const folfoxModule = require('./extractors/folfox')(debug);
const availableTestsModule = require('./extractors/availableTests')(debug);
const importantNotesModule = require('./extractors/importantNotes')(debug);

module.exports = (version) => async (fileContents) => {
  if (!fileContents) {
    debug('Empty data, skipping');
    return null;
  }

  const parser = new xml2js.Parser();
  debug('Parsing XML contents into JS');
  const obj = await parser.parseStringPromise(fileContents);

  debug('Parsing Report');
  return {
    version,
    header: headerModule(obj),
    specimen: specimenModule(obj),
    drugs: drugsModule(obj),
    folfox: folfoxModule(obj),
    cancerRelevantBiomarkers: cancerRelevantModule(obj),
    genomicSignatures: genomicSignaturesModule(obj),
    trackResults: trackResultsModule(obj),
    genes: genesModule(obj),
    hla: hlaTestsModule(obj),
    ihc: ihcModule(obj),
    gps: gpsModule(obj),
    cish: cishModule(obj),
    fish: fishModule(obj),
    ctcTrials: ctcTrialsModule(obj),
    references: referencesModule(obj),
    availableTests: availableTestsModule(obj),
    importantNotes: importantNotesModule(obj)
  };
};
