# XML Report Reader

[![NPM Version](https://img.shields.io/npm/v/@carisls/xmlreport-reader.svg?style=flat)](https://www.npmjs.org/package/@carisls/xmlreport-reader)
[![NPM Downloads](https://img.shields.io/npm/dm/@carisls/xmlreport-reader.svg?style=flat)](https://npmcharts.com/compare/@carisls/xmlreport-reader?minimal=true)
[![Install Size](https://packagephobia.now.sh/badge?p=%40carisls%2Fxmlreport-reader)](https://packagephobia.now.sh/result?p=%40carisls%2Fxmlreport-reader)

The purpose of this component is reading of standard XML documents with genomics data
created by Caris Life Sciences.

It can be used from inside Node.js application [API](#api-usage)
or as an executable [CLI](#cli-usage).

## Installation

```sh
npm i @carisls/xmlreport-reader
```

If you want to use it globally (not only inside application folder) you can
install it with `-g` flag.

```sh
npm i -g @carisls/xmlreport-reader
```

## API Usage
```javascript
const xmlReader = require('@carisls/xmlreport-reader');

const { promises: fs } = require('fs');

(async() => {
  // Get XML file contents
  const fileContents = await fs.readFile('./myfile.xml', 'utf8');

  // Parse XML into Report
  const report = xmlReader(fileContents);

  // Prettify report JSON
  const reportString = JSON.stringify(report, null, 2);

  // Write to console
  console.log(reportString);

})()
  .catch((err) => {
    console.error(err);
  });

```

## CLI Usage

This component can be run as a CLI, too (outside an application).

```sh
xmlreport file.xml
```

If you want to print its output into some file, you can execute
```sh
xmlreport file.xml > output.json
```

## Supported elements
Only few elements are currently supported for extraction:
- Cancer-Relevant Biomarkers
- Genomic Signatures
- Immunohistochemistry (IHC)
- Human Leukocyte Antigen (HLA)
- Available Clinical Trials
- References (supporting treatments)
