module.exports = (debug) => (xml) => {
  debug('Genes', 'Processing started');
  const sourceP = xml.root.report?.[0].ngsAltTestSet?.[0].ngsAltTest;
  const sourceU = xml.root.report?.[0].ngsVusAltTestSet?.[0].ngsAltTest;

  if(!sourceP && !sourceU) {
    debug('Genes', 'Data not available');
    return undefined;
  }

  function extractGene (i) {
    return {
      biomarker: i.gene?.[0].replace(/(\r\n|\n|\r)/gm,""),
      method: i.method?.[0].replace(/(\r\n|\n|\r)/gm,""),
      analyte: i.analyte?.[0].replace(/(\r\n|\n|\r)/gm,""),
      result: i.result?.[0].trim().replace(/(\r\n|\n|\r)/gm,""),
      proteinChange: (i.analyte?.[0].match(/RNA/i) ? i.fusionIsoform?.[0] : i.alteration?.[0])?.trim() || '',
      dnaChange: i.dnaChange?.[0].trim() || '',
      exon: i.exon?.[0].trim(),
      gene1: i.fusionIsoform?.[0],
      variantFrequency: parseFloat(i.mutated?.[0]) || null,
      interpretation: i.interpretation?.[0].trim().replace(/(\r\n|\n|\r)/gm,""),
      summary: i.summary?.[0].trim().replace(/(\r\n|\n|\r)/gm,"")
    };
  }

  let genesP;
  let genesU;

  try {
    if(sourceP?.length) {
      debug('Genes', 'Extracting pathogenic genes started');
      genesP = sourceP.map(extractGene);
      debug('Genes', 'Extracting pathogenic genes finished');
    }
    else {
      debug('Genes', 'Pathogenic genes source not available');
      genesP = [];
    }

    if(sourceU?.length) {
      debug('Genes', 'Extracting uncertain genes started');
      genesU = sourceU.map(extractGene);
      debug('Genes', 'Extracting uncertain genes finished');
    }
    else {
      debug('Genes', 'Uncertain genes source not available');
      genesU = [];
    }
  }
  catch(err) {
    debug('Genes', err);
    return undefined;
  }

  debug('GenesPathogenic', 'Processing finished');
  return [...genesP, ...genesU];
}
